# Universal Greetings Library for Python

Universal Greetings  description


## Get started

```bash
poetry add universal-greetings
```

```python
from universalgreetings import Hello

hello=Hello()

hello.sayHello()

```
